AdvancedMarkersController class
A MarkersController for the advanced gmaps.AdvancedMarkerElement class.
- Inheritance
-
- Object
- MarkersController<
AdvancedMarkerElement, AdvancedMarkerElementOptions> - AdvancedMarkersController
Constructors
-
AdvancedMarkersController({required StreamController<
MapEvent< stream, required ClusterManagersController<Object?> >AdvancedMarkerElement> clusterManagersController}) -
Initialize the markers controller for advanced markers
(
gmaps.AdvancedMarkerElement).
Properties
- googleMap ↔ Map
-
The GMap instance that this controller operates on.
getter/setter pairinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- mapId ↔ int
-
The map ID for events.
getter/setter pairinherited
-
markers
→ Map<
MarkerId, MarkerController< AdvancedMarkerElement, AdvancedMarkerElementOptions> > -
Returns the cache of MarkerControllers. Test only.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
addMarkers(
Set< Marker> markersToAdd) → Future<void> -
Adds a set of
Markerobjects to the cache.inherited -
bindToMap(
int mapId, Map googleMap) → void -
Binds a
mapIdand thegmaps.Mapinstance to this controller.inherited -
changeMarkers(
Set< Marker> markersToChange) → Future<void> -
Updates a set of
Markerobjects with new options.inherited -
createMarkerController(
Marker marker, AdvancedMarkerElementOptions markerOptions, InfoWindow? gmInfoWindow) → Future< AdvancedMarkerController> -
Creates a MarkerController for the given
marker.override -
hideMarkerInfoWindow(
MarkerId markerId) → void -
Hides the
InfoWindowof aMarkerId.inherited -
isInfoWindowShown(
MarkerId markerId) → bool -
Returns whether or not the
InfoWindowof aMarkerIdis shown.inherited -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
removeMarkers(
Set< MarkerId> markerIdsToRemove) → void -
Removes a set of
MarkerIds from the cache.inherited -
showMarkerInfoWindow(
MarkerId markerId) → void -
Shows the
InfoWindowof aMarkerId.inherited -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited