HeatmapController class
The HeatmapController class wraps a visualization.HeatmapLayer and its onTap behavior.
Constructors
- HeatmapController({required HeatmapLayer heatmap})
-
Creates a
HeatmapController, which wraps avisualization.HeatmapLayerobject and itsonTapbehavior.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- heatmap → HeatmapLayer?
-
Returns the wrapped
visualization.HeatmapLayer. Only used for testing.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
remove(
) → void -
Disposes of the currently wrapped
visualization.HeatmapLayer. -
toString(
) → String -
A string representation of this object.
inherited
-
update(
HeatmapLayerOptions options) → void -
Updates the options of the wrapped
visualization.HeatmapLayerobject.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited